Name:		liblas
Version:	1.8.0
Release:	23%{?dist}
Summary:	Library for reading and writing the very common LAS LiDAR format

Group:		System Environment/Libraries
License:	BSD and Boost
URL:		http://www.liblas.org
Source0:	http://download.osgeo.org/%{name}/libLAS-%{version}.tar.bz2

BuildRequires:  gcc-c++
BuildRequires:	boost-devel >= 1.53
BuildRequires:	cmake
BuildRequires:	gdal-devel
BuildRequires:	laszip-devel
BuildRequires:	libgeotiff-devel

%description
libLAS is a C/C++ library for reading and writing the very common LAS LiDAR
format. The ASPRS LAS format is a sequential binary format used to store
data from LiDAR sensors and by LiDAR processing software for data
interchange and archival.

%package devel
Summary:	libLAS development files
Group:		Development/Libraries
Requires:	%{name}%{?_isa} = %{version}-%{release}

Requires:	boost-devel >= 1.53
Requires:	gdal-devel
Requires:	laszip-devel
Requires:	libgeotiff-devel

%description devel
libLAS deveolpment files.

%package tools
Summary:	libLAS utility applications
Group:		Development/Libraries
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description tools
libLAS utility applications.

%prep
%setup -q -n libLAS-%{version}
sed -i -e 's#@libdir@#%{_libdir}#' \
	-e 's#@Boost_PROGRAM_OPTIONS_LIBRARY_RELEASE@#-lboost_program_options#' \
	-e 's#@Boost_THREAD_LIBRARY_RELEASE@#-lboost_thread#' \
	-e 's#@GDAL_LIBRARY@#-lgdal#' \
	-e 's#@GEOTIFF_LIBRARY@#-lgeotiff#' \
	-e 's#@TIFF_LIBRARY@#-ltiff#' \
	-e 's#@LASZIP_LIBRARY@#-llaszip#' \
	%{_builddir}/libLAS-%{version}/apps/liblas-config.in

%build
%cmake \
	-DCMAKE_BUILD_TYPE:STRING="Release" \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DGEOTIFF_INCLUDE_DIR:PATH="%{_includedir}/libgeotiff" \
	-DLIBLAS_LIB_SUBDIR:PATH="%{_lib}" \
	-DWITH_PKGCONFIG:BOOL=OFF \
	-DWITH_TESTS:BOOL=OFF .
make %{?_smp_mflags}

%install
%make_install

%postun -p /sbin/ldconfig
%post -p /sbin/ldconfig

%files
%exclude %{_datadir}/%{name}/
%{_libdir}/*.so.*

%files devel
%license LICENSE.txt
%{_bindir}/liblas-config
%{_datadir}/cmake/libLAS-%{version}/
%{_includedir}/%{name}/
%{_libdir}/*.so

%files tools
%doc AUTHORS README.txt
%exclude %{_bindir}/liblas-config
%{_bindir}/*

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-23
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 23 2018 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-21
- Rebuilt for Boost 1.66

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Jul 19 2017 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-18
- Rebuilt for s390x binutils bug

* Mon Jul 03 2017 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-17
- Rebuilt for Boost 1.64

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-15
- Rebuilt for Boost 1.63

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-14
- Rebuilt for Boost 1.63

* Tue May 17 2016 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-13
- Rebuilt for linker errors in boost (#1331983)

* Tue Mar 15 2016 Thomas Kreuzer <thomas.kreuzer@uni-vechta.de> - 1.8.0-12
- Put licence file into correct place.

* Thu Mar 10 2016 Thomas Kreuzer <thomas.kreuzer@uni-vechta.de> - 1.8.0-11
- Fix bug #1311953

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 15 2016 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-9
- Rebuilt for Boost 1.60

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 1.8.0-8
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-7
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Mon Jul 27 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.8.0-6
- Rebuilt for libgdal

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 1.8.0-5
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Apr 17 2015 Devrim GUNDUZ <devrim@gunduz.org> 1.8.0-3
- Various updates, per Fedora review from Rex:
 - Update license
 - omit INSTALL from %%doc
 - Own directories in -devel subpackage
 - omit deprecated Group: tags and %%clean section
 - Use better macros for make and cmake
 - use %%%{?_isa} macro in subpkg dependencies
 - have %%build section envoke 'make'
 - Update %%install section
 - Improve cmake build parameters, also fix rpath
 - move liblaszip.so symlink to -devel subpkg
 - move liblas-config to -devel subpackage
 - Split -devel and -libs subpackages

* Fri Apr 17 2015 Devrim GUNDUZ <devrim@gunduz.org> 1.8.0-2
- Various updates:
  * Split -devel and -libs subpackages
  * Use %%license macro
  * Use %%make_install macro
  * Get rid of BuildRoot definition
  * No need to cleanup buildroot during %%install
  * Remove %%defattr
  * Run ldconfig
  * Fix version numbers in spec file
  * BR laszip-devel, and require laszip, per recent laszip changes.

* Tue Jan 13 2015 Devrim GUNDUZ <devrim@gunduz.org> 1.8.0-1
- Initial packaging
